@@ -6,7 +6,7 @@ use warnings;
 use Algorithm::Combinatorics qw(subsets variations);
 no if $] >= 5.017011, warnings => 'experimental::smartmatch';
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 my$self;
 
@@ -19,12 +19,18 @@ sub new{
 	my $class = ref($type)||$type;
 	$self = {
 		totalTransactions => 0,
-		minSupport => 1,
-		minConfidence => undef,
-		minLift => undef,
-		minLeverage => undef,
-		minConviction => undef,
-		minCoverage => undef,
+		metrics => {
+			minSupport => 0.01,
+			minConfidence => 0.10,
+			minLift => undef,
+			minLeverage => undef,
+			minConviction => undef,
+			minCoverage => undef,
+			minCorrelation => undef,
+			minCosine => undef,
+			minLaplace => undef,
+			minJaccard => undef
+		},
 		output => undef,
 		messages => undef,
 		itemsKeyDescription => undef,
@@ -84,11 +90,11 @@ sub quantity_possible_rules{
 
 sub generate_rules{
 	$self->validate_data;
-	my @largeItemsetSizeOne = $self->data_persistence;
+	my @largeItemsetSizeOne = keys(%{$self->{itemsKeyDescription}});
 	if($self->{messages}){
 		print "\n${\scalar(keys(%{$self->{itemsKeyDescription}}))} items, ${\$self->quantity_possible_rules} possible rules";
 	}
-	my @frequentItemset = grep{(($self->{itemsKeyTransactions}{$_}/$self->{totalTransactions})*100)>=$self->{minSupport}}@largeItemsetSizeOne;
+	my @frequentItemset = grep{(($self->{itemsKeyTransactions}{$_}/$self->{totalTransactions})*100)>=$self->{metrics}{minSupport}}@largeItemsetSizeOne;
 	$self->association_rules(\@frequentItemset);
 }
 
@@ -118,24 +124,44 @@ sub association_rules{
 			push@implication,@antecedent,@consequent;
 			@implication=sort(@implication);
 			next unless $self->{itemsKeyTransactions}{"@antecedent"};
-			my$supportAntecedent=$self->{itemsKeyTransactions}{"@antecedent"};
+			my$supportAntecedent=($self->{itemsKeyTransactions}{"@antecedent"}/$self->{totalTransactions});
 			next unless $self->{itemsKeyTransactions}{"@implication"};
-			my$supportConsequent=$self->{itemsKeyTransactions}{"@implication"};
-			my $support = sprintf("%.2f",(($supportConsequent/$self->{totalTransactions})*100));
-			next if($support<$self->{minSupport});
-			my $confidence = sprintf("%.2f",(($supportConsequent/$supportAntecedent)*100));
-			next if(defined $self->{minConfidence} && $confidence < $self->{minConfidence});
-			my $lift = sprintf("%.2f",($support/($supportAntecedent*$supportConsequent)));
-			next if(defined $self->{minLift} && $lift < $self->{minLift});
-			my $leverage = sprintf("%.2f",($support-($supportAntecedent*$supportConsequent)));
-			next if(defined $self->{minLeverage} && $leverage < $self->{minLeverage});	
-			my $conviction = sprintf("%.2f",((1-$supportAntecedent)/(1-$confidence)));
-			next if(defined $self->{minConviction} && $conviction < $self->{minConviction});
-			my $coverage = sprintf("%.2f",(($supportAntecedent/$self->{totalTransactions})*100));
-			next if(defined $self->{minCoverage} && $coverage < $self->{minCoverage});
+			my$supportConsequent=($self->{itemsKeyTransactions}{"@implication"}/$self->{totalTransactions});
+			my $support = $supportConsequent;
+			next if($support < $self->{metrics}{minSupport});
+			my $confidence = ($supportConsequent/$supportAntecedent);
+			next if(defined $self->{metrics}{minConfidence} && $confidence < $self->{metrics}{minConfidence});
+			my $lift = ($support/($supportAntecedent*$supportConsequent));
+			next if(defined $self->{metrics}{minLift} && $lift < $self->{metrics}{minLift});
+			my $leverage = ($support-($supportAntecedent*$supportConsequent));
+			next if(defined $self->{metrics}{minLeverage} && $leverage < $self->{metrics}{minLeverage});
+			my $conviction = ((1-$supportConsequent)==0)?"NaN":((1-$confidence)==0)?"NaN":((1-$supportConsequent)/(1-$confidence));
+			next if(defined $self->{metrics}{minConviction} && $conviction < $self->{metrics}{minConviction});
+			my $coverage = $supportAntecedent;
+			next if(defined $self->{metrics}{minCoverage} && $coverage < $self->{metrics}{minCoverage});
+			my $correlation = (($support-($supportAntecedent*$supportConsequent))/sqrt($supportAntecedent*(1-$supportAntecedent)*$supportConsequent*(1-$supportConsequent)));
+			next if(defined $self->{metrics}{minCorrelation} && $correlation < $self->{metrics}{minCorrelation});
+			my $cosine = ($support/sqrt($supportAntecedent*$supportConsequent));
+			next if(defined $self->{metrics}{minCosine} && $cosine < $self->{metrics}{minCosine});
+			my $laplace = (($support+1)/($supportAntecedent+2));
+			next if(defined $self->{metrics}{minLaplace} && $laplace < $self->{metrics}{minLaplace});
+			my $jaccard = ($support/($supportAntecedent+$supportConsequent-$support));
+			next if(defined $self->{metrics}{minJaccard} && $jaccard < $self->{metrics}{minJaccard});
 			$self->{rule}++;
-			$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{rule} = ["{ @antecedent } => { @consequent }", $support, $confidence, $lift, $leverage, $conviction, $coverage];
-			$self->{associationRules}{$self->{rule}}{"R$self->{rule}"}{items} = [@antecedent, @consequent];
+			$self->{associationRules}{$self->{rule}} = {
+				implication => "{ @antecedent } => { @consequent }",
+				support => sprintf("%.4f", $support), 
+				confidence => sprintf("%.4f", $confidence),
+				lift => sprintf("%.4f", $lift),
+				leverage => sprintf("%.4f", $leverage),
+				conviction => sprintf("%.4f", $conviction),
+				coverage => sprintf("%.4f", $coverage),
+				correlation => sprintf("%.4f", $correlation),
+				cosine => sprintf("%.4f", $cosine),
+				laplace => sprintf("%.4f", $laplace),
+				jaccard => sprintf("%.4f", $jaccard),
+				items => [@antecedent, @consequent]
+			};
 			my@items=grep{!($_~~@frequentItemset)}@implication;
 			push@frequentItemset,@items;
 		}
@@ -164,16 +190,10 @@ sub stop{
 		my $answer = <STDIN>;
 		chomp($answer);
 		if($answer =~ /^y$/i){
-			print "Save data for further processing in the next run? (Y/N): ";
-			$answer = <STDIN>;
-			chomp($answer);
-			if($answer =~ /^y$/i){
-				$self->data_persistence;
-			}
 			exit;
 		}
 		else{
-			print "\nProcessing... ";
+			print "Processing... ";
 		}
 	}
 	else{
@@ -193,66 +213,42 @@ sub output{
 	}
 }
 
-sub data_persistence{
-	use Storable;
-	if(wantarray){
-		if(-e 'Apriori.storable'){
-			print "\nContinue processing using the data saved in the last run? (Y/N): ";
-			my$answer = <STDIN>;
-			chomp($answer);
-			if($answer =~ /^y$/i){
-				$self = retrieve('Apriori.storable');
-				unlink('Apriori.storable');
-				return @{$self->{frequentItemset}};
-			}
-			else{
-				unlink('Apriori.storable');
-				return keys(%{$self->{itemsKeyDescription}});
-			}
-		}
-		else{
-			return keys(%{$self->{itemsKeyDescription}});
-		}
-	}
-	else{
-		store($self,'Apriori.storable');
-	}
-}
-
 sub file{
 	if($self->{messages}){
 		print "\nExporting to file \"output_large_itemset_size_$self->{largeItemsetSize}.txt\"... ";
 	}
 	open(FILE,">output_large_itemset_size_$self->{largeItemsetSize}.txt")
 		or die("\nError: \"output_large_itemset_size_$self->{largeItemsetSize}.txt\" $!");
-	print FILE "Rules\tSupport %";
-	print FILE "\tConfidence %" if defined $self->{minConfidence};
-	print FILE "\tLift" if defined $self->{minLift};
-	print FILE "\tLeverage" if defined $self->{minLeverage};
-	print FILE "\tConviction" if defined $self->{minConviction};
-	print FILE "\tCoverage %" if defined $self->{minCoverage};
+	print FILE "Rules\tSupport\tConfidence";
+	my@headings=('Lift', 'Leverage', 'Conviction', 'Coverage', 'Correlation', 'Cosine', 'Laplace', 'Jaccard');
+	my@metrics;
+	foreach my$metric(@headings){
+		push@metrics,$metric if defined $self->{metrics}{"min$metric"};
+	}
+	foreach my$metric(@metrics){
+		print FILE "\t$metric";
+	}
 	print FILE "\n";
 	foreach my$rule(sort{$a<=>$b}keys(%{$self->{associationRules}})){
-		foreach(@{$self->{associationRules}{$rule}{"R$rule"}{rule}}){s/\./,/;}
-		print FILE "R$rule\t${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[1]";
-		print FILE "\t${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[2]" if defined $self->{minConfidence};
-		print FILE "\t${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[3]" if defined $self->{minLift};
-		print FILE "\t${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[4]" if defined $self->{minLeverage};
-		print FILE "\t${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[5]" if defined $self->{minConviction};
-		print FILE "\t${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[6]" if defined $self->{minCoverage};
+		foreach my$metric(@metrics){
+			$self->{associationRules}{$rule}{lc$metric}=~s/\./,/;
+		}
+		print FILE "R$rule\t$self->{associationRules}{$rule}{support}\t$self->{associationRules}{$rule}{confidence}";
+		foreach my$metric(@metrics){
+			print FILE "\t$self->{associationRules}{$rule}{${\lc$metric}}";
+		}
 		print FILE "\n";
 	}
 	print FILE "\n";
 	foreach my$rule(sort{$a<=>$b}keys(%{$self->{associationRules}})){
-		print FILE "Rule R$rule: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[0]\n";
-		print FILE "Support: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[1] %\n";
-		print FILE "Confidence: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[2] %\n" if defined $self->{minConfidence};
-		print FILE "Lift: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[3]\n" if defined $self->{minLift};
-		print FILE "Leverage: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[4]\n" if defined $self->{minLeverage};
-		print FILE "Conviction: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[5]\n" if defined $self->{minConviction};
-		print FILE "Coverage: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[6] %\n" if defined $self->{minCoverage};
+		print FILE "Rule R$rule: $self->{associationRules}{$rule}{implication}\n";
+		print FILE "Support: $self->{associationRules}{$rule}{support}\n";
+		print FILE "Confidence: $self->{associationRules}{$rule}{confidence}\n";
+		foreach my$metric(@metrics){
+			print FILE "$metric: $self->{associationRules}{$rule}{${\lc$metric}}\n";
+		}
 		print FILE "Items:\n";
-		foreach my$item(@{$self->{associationRules}{$rule}{"R$rule"}{items}}){
+		foreach my$item(@{$self->{associationRules}{$rule}{items}}){
 			print FILE "$item $self->{itemsKeyDescription}{$item}\n";
 		}
 		print FILE "\n";
@@ -274,109 +270,76 @@ sub excel{
 		or die("\nError: \"output_large_itemset_size_$self->{largeItemsetSize}.xlsx\" $!");
 	my $worksheet = $workbook->add_worksheet();
 	my $bold = $workbook->add_format(bold => 1);
-	my $headings = ['Rules', 'Support %'];
-	push @{$headings},'Confidence %' if defined $self->{minConfidence};
-	push @{$headings},'Lift' if defined $self->{minLift};
-	push @{$headings},'Leverage' if defined $self->{minLeverage};
-	push @{$headings},'Conviction' if defined $self->{minConviction};
-	push @{$headings},'Coverage %' if defined $self->{minCoverage};
-	my(@rules,@support,@confidence,@lift,@leverage,@conviction,@coverage);	
+	my $headings = ['Rules', 'Support', 'Confidence'];
+	my@metrics=('Lift', 'Leverage', 'Conviction', 'Coverage', 'Correlation', 'Cosine', 'Laplace', 'Jaccard');
+	foreach my$metric(@metrics){
+		push@{$headings},$metric if defined $self->{metrics}{"min$metric"};
+	}
+	@metrics=@{$headings}[3..$#{$headings}];
+	my(@rules,@support,@confidence,@lift,@leverage,@conviction,@coverage,@correlation,@cosine,@laplace,@jaccard);	
 	foreach my$rule(sort{$a<=>$b}keys(%{$self->{associationRules}})){
 		push @rules,"R$rule";
-		push @support,${$self->{associationRules}{$rule}{"R$rule"}{rule}}[1];
-		push @confidence,${$self->{associationRules}{$rule}{"R$rule"}{rule}}[2] if defined $self->{minConfidence};
-		push @lift,${$self->{associationRules}{$rule}{"R$rule"}{rule}}[3] if defined $self->{minLift};
-		push @leverage,${$self->{associationRules}{$rule}{"R$rule"}{rule}}[4] if defined $self->{minLeverage};
-		push @conviction,${$self->{associationRules}{$rule}{"R$rule"}{rule}}[5] if defined $self->{minConviction};
-		push @coverage,${$self->{associationRules}{$rule}{"R$rule"}{rule}}[6] if defined $self->{minCoverage};
+		push @support,$self->{associationRules}{$rule}{support};
+		push @confidence,$self->{associationRules}{$rule}{confidence};
+		push @lift,$self->{associationRules}{$rule}{lift} if defined $self->{metrics}{minLift};
+		push @leverage,$self->{associationRules}{$rule}{leverage} if defined $self->{metrics}{minLeverage};
+		push @conviction,$self->{associationRules}{$rule}{conviction} if defined $self->{metrics}{minConviction};
+		push @coverage,$self->{associationRules}{$rule}{coverage} if defined $self->{metrics}{minCoverage};
+		push @correlation,$self->{associationRules}{$rule}{correlation} if defined $self->{metrics}{minCorrelation};
+		push @cosine,$self->{associationRules}{$rule}{cosine} if defined $self->{metrics}{minCosine};
+		push @laplace,$self->{associationRules}{$rule}{laplace} if defined $self->{metrics}{minLaplace};
+		push @jaccard,$self->{associationRules}{$rule}{jaccard} if defined $self->{metrics}{minJaccard};
 	}
 	my$line=(scalar(@rules)+1);
-	my@data=(\@rules,\@support,);
-	push @data,\@confidence if defined $self->{minConfidence};
-	push @data,\@lift if defined $self->{minLift};
-	push @data,\@leverage if defined $self->{minLeverage};
-	push @data,\@conviction if defined $self->{minConviction};
-	push @data,\@coverage if defined $self->{minCoverage};
+	my@data=(\@rules,\@support,\@confidence);
+	push @data,\@lift if defined $self->{metrics}{minLift};
+	push @data,\@leverage if defined $self->{metrics}{minLeverage};
+	push @data,\@conviction if defined $self->{metrics}{minConviction};
+	push @data,\@coverage if defined $self->{metrics}{minCoverage};
+	push @data,\@correlation if defined $self->{metrics}{minCorrelation};
+	push @data,\@cosine if defined $self->{metrics}{minCosine};
+	push @data,\@laplace if defined $self->{metrics}{minLaplace};
+	push @data,\@jaccard if defined $self->{metrics}{minJaccard};
 	$worksheet->write('A1', $headings, $bold);
 	$worksheet->write('A2', \@data);
 	my$chart=$workbook->add_chart(type => 'column', embedded => 1);
-	my@columns=('B'..'G');
+	my@columns=('B'..'M');
 	my$i=0;
 	$chart->add_series(
-		name       => 'Support %',
+		name       => 'Support',
 		categories => '=Sheet1!$A$2:$A$'.$line,
 		values     => '=Sheet1!$'.$columns[$i].'$2:$'.$columns[$i].'$'.$line,
 	);
-	if(defined $self->{minConfidence}){
+	$i++;
+	$chart->add_series(
+		name       => 'Confidence',
+		categories => '=Sheet1!$A$2:$A$'.$line,
+		values     => '=Sheet1!$'.$columns[$i].'$2:$'.$columns[$i].'$'.$line,
+	);
+	foreach my$metric(@metrics){
 		$i++;
 		$chart->add_series(
-			name       => 'Confidence %',
+			name       => $metric,
 			categories => '=Sheet1!$A$2:$A$'.$line,
 			values     => '=Sheet1!$'.$columns[$i].'$2:$'.$columns[$i].'$'.$line,
 		);
 	}
-	if(defined $self->{minLift}){
-		$i++;
-		$chart->add_series(
-			name       => 'Lift',
-			categories => '=Sheet1!$A$2:$A$'.$line,
-			values     => '=Sheet1!$'.$columns[$i].'$2:$'.$columns[$i].'$'.$line,
-		);
-	}
-	if(defined $self->{minLeverage}){
-		$i++;
-		$chart->add_series(
-			name       => 'Leverage',
-			categories => '=Sheet1!$A$2:$A$'.$line,
-			values     => '=Sheet1!$'.$columns[$i].'$2:$'.$columns[$i].'$'.$line,
-		);
-	}
-	if(defined $self->{minConviction}){
-		$i++;
-		$chart->add_series(
-			name       => 'Conviction',
-			categories => '=Sheet1!$A$2:$A$'.$line,
-			values     => '=Sheet1!$'.$columns[$i].'$2:$'.$columns[$i].'$'.$line,
-		);
-	}
-	if(defined $self->{minCoverage}){
-		$i++;
-		$chart->add_series(
-			name       => 'Coverage %',
-			categories => '=Sheet1!$A$2:$A$'.$line,
-			values     => '=Sheet1!$'.$columns[$i].'$2:$'.$columns[$i].'$'.$line,
-		);
-	}
-	$worksheet->insert_chart('I2', $chart);
+	$worksheet->insert_chart($columns[($i+2)].'2', $chart);
 	$line+=2;
 	foreach my$rule(sort{$a<=>$b}keys(%{$self->{associationRules}})){
-		$worksheet->write("A$line","Rule R$rule: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[0]");
+		$worksheet->write("A$line","Rule R$rule: $self->{associationRules}{$rule}{implication}");
 		$line++;
-		$worksheet->write("A$line","Support: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[1] %");
+		$worksheet->write("A$line","Support: $self->{associationRules}{$rule}{support}");
 		$line++;
-		if(defined $self->{minConfidence}){
-			$worksheet->write("A$line","Confidence: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[2] %");
-			$line++;
-		}
-		if(defined $self->{minLift}){
-			$worksheet->write("A$line","Lift: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[3]");
-			$line++;
-		}
-		if(defined $self->{minLeverage}){
-			$worksheet->write("A$line","Leverage: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[4]");
-			$line++;
-		}
-		if(defined $self->{minConviction}){
-			$worksheet->write("A$line","Conviction: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[5]");
-			$line++;
-		}
-		if(defined $self->{minCoverage}){
-			$worksheet->write("A$line","Coverage: ${$self->{associationRules}{$rule}{\"R$rule\"}{rule}}[6] %");
+		$worksheet->write("A$line","Confidence: $self->{associationRules}{$rule}{confidence}");
+		$line++;
+		foreach my$metric(@metrics){
+			$worksheet->write("A$line","$metric: $self->{associationRules}{$rule}{${\lc$metric}}");
 			$line++;
 		}
 		$worksheet->write("A$line","Items:");
 		$line++;
-		foreach my$item(@{$self->{associationRules}{$rule}{"R$rule"}{items}}){
+		foreach my$item(@{$self->{associationRules}{$rule}{items}}){
 			$worksheet->write("A$line","$item $self->{itemsKeyDescription}{$item}");
 			$line++;
 		}
@@ -419,17 +382,25 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 
 	my $apriori = new Data::Mining::Apriori;
 
-	$apriori->{minSupport}=1.55; # The minimum support, default values is 1(percent)
+	$apriori->{metrics}{minSupport}=0.0155; # The minimum support, default value is 0.01(1%)
 
-	$apriori->{minConfidence}=1.55; # The minimum confidence(percent, optional)
+	$apriori->{metrics}{minConfidence}=0.0155; # The minimum confidence, default value is 0.10(10%)
 
-	$apriori->{minLift}=1; # The minimum lift(optional)
+	$apriori->{metrics}{minLift}=1; # The minimum lift(optional)
 
-	$apriori->{minLeverage}=0; # The minimum leverage(optional)
+	$apriori->{metrics}{minLeverage}=0; # The minimum leverage(optional)
 
-	$apriori->{minConviction}=0; # The minimum conviction(optional)
+	$apriori->{metrics}{minConviction}=0; # The minimum conviction(optional)
 
-	$apriori->{minCoverage}=0; # The minimum coverage(percent, optional)
+	$apriori->{metrics}{minCoverage}=0; # The minimum coverage(optional)
+
+	$apriori->{metrics}{minCorrelation}=0; # The minimum correlation(optional)
+
+	$apriori->{metrics}{minCosine}=0; # The minimum cosine(optional)
+
+	$apriori->{metrics}{minLaplace}=0; # The minimum laplace(optional)
+
+	$apriori->{metrics}{minJaccard}=0; # The minimum jaccard(optional)
 
 	$apriori->{output}=1;
 	# The output type (1 - Export to text file delimited by tab; 2 - Export to excel file with chart)(optional)
@@ -457,7 +428,7 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 	$apriori->input_data_file("datafile.txt",",");
 	# Insert items per line(transaction), accepts the arguments of path to data file and item separator
 
-	# file contents
+	# file contents (example)
 
 	103,101
 	103,102
@@ -495,58 +466,72 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 
 	#output file "output_itemset_size_2.txt"
 
-	Rules	Support %	Confidence %	Lift	Leverage	Conviction	Coverage %
-	R1	70,00	77,78	1,11	7,00	0,10	90,00
-	R2	80,00	88,89	1,11	8,00	0,09	90,00
-	R3	70,00	87,50	1,25	14,00	0,08	80,00
-	R4	70,00	87,50	1,25	14,00	0,08	80,00
-	R5	80,00	88,89	1,11	8,00	0,09	90,00
-	R6	70,00	77,78	1,11	7,00	0,10	90,00
+	Rules	Support	Confidence	Lift	Leverage	Conviction	Coverage	Correlation	Cosine	Laplace	Jaccard
+	R1	0.7000	0.7778	1,1111	0,0700	1,3500	0,9000	0,5092	0,8819	0,5862	0,7778
+	R2	0.8000	0.8889	1,1111	0,0800	1,8000	0,9000	0,6667	0,9428	0,6207	0,8889
+	R3	0.7000	0.8750	1,2500	0,1400	2,4000	0,8000	0,7638	0,9354	0,6071	0,8750
+	R4	0.7000	0.8750	1,2500	0,1400	2,4000	0,8000	0,7638	0,9354	0,6071	0,8750
+	R5	0.8000	0.8889	1,1111	0,0800	1,8000	0,9000	0,6667	0,9428	0,6207	0,8889
+	R6	0.7000	0.7778	1,1111	0,0700	1,3500	0,9000	0,5092	0,8819	0,5862	0,7778
 
-	Rule R1: { 103 } => { 101 }
-	Support: 70,00 %
-	Confidence: 77,78 %
-	Lift: 1,11
-	Leverage: 7,00
-	Conviction: 0,10
-	Coverage: 90,00 %
+	Rule R1: { 102 } => { 101 }
+	Support: 0.7000
+	Confidence: 0.7778
+	Lift: 1,1111
+	Leverage: 0,0700
+	Conviction: 1,3500
+	Coverage: 0,9000
+	Correlation: 0,5092
+	Cosine: 0,8819
+	Laplace: 0,5862
+	Jaccard: 0,7778
 	Items:
-	103 CEREAL
+	102 BREAD
 	101 MILK
 
 	to be continued...
 
 	#output file "output_itemset_size_3.txt"
 
-	Rules	Support %	Confidence %	Lift	Leverage	Conviction	Coverage %
-	R7	60,00	66,67	1,11	6,00	0,12	90,00
-	R8	60,00	85,71	1,43	18,00	0,07	70,00
-	R9	60,00	75,00	1,25	12,00	0,09	80,00
-	R10	60,00	75,00	1,25	12,00	0,09	80,00
+	Rules	Support	Confidence	Lift	Leverage	Conviction	Coverage	Correlation	Cosine	Laplace	Jaccard
+	R7	0.6000	0.7500	1,2500	0,1200	1,6000	0,8000	0,6124	0,8660	0,5714	0,7500
+	R8	0.6000	0.8571	1,4286	0,1800	2,8000	0,7000	0,8018	0,9258	0,5926	0,8571
+	R9	0.6000	0.8571	1,4286	0,1800	2,8000	0,7000	0,8018	0,9258	0,5926	0,8571
+	R10	0.6000	0.6667	1,1111	0,0600	1,2000	0,9000	0,4082	0,8165	0,5517	0,6667
+	R11	0.6000	0.7500	1,2500	0,1200	1,6000	0,8000	0,6124	0,8660	0,5714	0,7500
+	R12	0.6000	0.6667	1,1111	0,0600	1,2000	0,9000	0,4082	0,8165	0,5517	0,6667
 
-	Rule R7: { 103 } => { 101, 102 }
-	Support: 60,00 %
-	Confidence: 66,67 %
-	Lift: 1,11
-	Leverage: 6,00
-	Conviction: 0,12
-	Coverage: 90,00 %
-	Items:
-	103 CEREAL
-	101 MILK
-	102 BREAD
-
-	Rule R8: { 101, 103 } => { 102 }
-	Support: 60,00 %
-	Confidence: 85,71 %
-	Lift: 1,43
-	Leverage: 18,00
-	Conviction: 0,07
-	Coverage: 70,00 %
+	Rule R7: { 101 } => { 102, 103 }
+	Support: 0.6000
+	Confidence: 0.7500
+	Lift: 1,2500
+	Leverage: 0,1200
+	Conviction: 1,6000
+	Coverage: 0,8000
+	Correlation: 0,6124
+	Cosine: 0,8660
+	Laplace: 0,5714
+	Jaccard: 0,7500
 	Items:
 	101 MILK
-	103 CEREAL
 	102 BREAD
+	103 CEREAL
+
+	Rule R8: { 101, 102 } => { 103 }
+	Support: 0.6000
+	Confidence: 0.8571
+	Lift: 1,4286
+	Leverage: 0,1800
+	Conviction: 2,8000
+	Coverage: 0,7000
+	Correlation: 0,8018
+	Cosine: 0,9258
+	Laplace: 0,5926
+	Jaccard: 0,8571
+	Items:
+	101 MILK
+	102 BREAD
+	103 CEREAL
 
 	to be continued...
 
@@ -608,17 +593,25 @@ Data::Mining::Apriori - Perl extension for implement the apriori algorithm of da
 
 	my $apriori = new Data::Mining::Apriori;
 
-	$apriori->{minSupport}=1.55;
+	$apriori->{metrics}{minSupport}=0.0155;
 
-	$apriori->{minConfidence}=1.55;
+	$apriori->{metrics}{minConfidence}=0.0155;
 
-	$apriori->{minLift}=1;
+	$apriori->{metrics}{minLift}=1;
 
-	$apriori->{minLeverage}=0;
+	$apriori->{metrics}{minLeverage}=0;
 
-	$apriori->{minConviction}=0;
+	$apriori->{metrics}{minConviction}=0;
 
-	$apriori->{minCoverage}=0;
+	$apriori->{metrics}{minCoverage}=0;
+
+	$apriori->{metrics}{minCorrelation}=0;
+
+	$apriori->{metrics}{minCosine}=0;
+
+	$apriori->{metrics}{minLaplace}=0;
+
+	$apriori->{metrics}{minJaccard}=0;
 
 	$apriori->{output}=1;
 
@@ -675,33 +668,37 @@ This module implements the apriori algorithm of data mining.
 
 The total number of transactions.
 
-=head2 minSupport
+=head2 metrics
 
-The minimum support.(percent)
+The type of metrics
 
-=head2 minConfidence
+=over 4
 
-The minimum confidence.(percent, optional)
+=item * minSupport - the minimum support, default value is 0.01(1%);
 
-=head2 minLift
+=item * minConfidence - the minimum confidence, default value is 0.10(10%);
 
-The minimum lift.(optional)
+=item * minLift - the minimum lift(optional);
 
-=head2 minLeverage
+=item * minLeverage - the minimum leverage(optional);
 
-The minimum leverage.(optional)
+=item * minConviction - the minimum conviction(optional);
 
-=head2 minConviction
+=item * minCoverage - the minimum coverage(optional);
 
-The minimum conviction.(optional)
+=item * minCorrelation - the minimum correlation(optional);
 
-=head2 minCoverage
+=item * minCosine - the minimum cosine(optional);
 
-The minimum coverage.(percent, optional)
+=item * minLaplace - the minimum laplace(optional);
+
+=item * minJaccard - the minimum jaccard(optional).
+
+=back
 
 =head2 limitRules
 
-The limit of rules.(optional)
+The limit of rules(optional)
 
 =head2 output
 
@@ -717,7 +714,7 @@ The output type:(optional)
 
 =head2 messages
 
-A value boolean to display the messages.(optional)
+A value boolean to display the messages(optional)
 
 =head2 itemsKeyDescription
 
@@ -725,7 +722,7 @@ Hash table to add items by key and description.
 
 =head2 itemsKeyTransactions
 
-Reference to array, to add the transactions of each item per key.
+Hash table, to add the key items per transaction.
 
 =head2 frequentItemset
 
@@ -733,27 +730,28 @@ Frequent itemset.
 
 =head2 associationRules
 
-A data structure to store the name of the rule, key items, implication, support, confidence, lift, leverage, conviction and coverage.
+A data structure to store the name of the rule, key items, implication, support, confidence, lift, leverage, conviction, coverage, correlation, cosine, laplace and jaccard.
 
-	$self->{associationRules} = {
-                                    '1' => {
-                                                'R1' => {
-                                                            'items' => [
-                                                                         '103',
-                                                                         '101'
-                                                                       ],
-                                                            'rule' => [
-                                                                        '{ 103 } => { 101 }',
-                                                                        '70,00',
-                                                                        '77,78',
-                                                                        '1,11',
-                                                                        '7,00',
-                                                                        '0,10',
-                                                                        '90,00'
-                                                                      ]
-                                                        }
-                                            },
-                                            # to be continued...
+    $self->{associationRules} = {
+                                '1' => {
+                                       'implication' => '{ 102 } => { 101 }',
+                                       'support' => '0.7000',
+                                       'correlation' => '0,5092',
+                                       'jaccard' => '0,7778',
+                                       'confidence' => '0.7778',
+                                       'conviction' => '1,3500',
+                                       'leverage' => '0,0700',
+                                       'laplace' => '0,5862',
+                                       'cosine' => '0,8819',
+                                       'coverage' => '0,9000',
+                                       'lift' => '1,1111',
+                                       'items' => [
+                                                  '102',
+                                                  '101'
+                                                  ]
+                                        }
+                                },
+                                # to be continued...
 
 =head1 METHODS
 
@@ -783,13 +781,26 @@ Insert items per line(transaction). Accepts the following arguments:
 
 =back
 
+	# file contents (example)
+
+	103,101
+	103,102
+	103,101,102
+	103,101,102
+	101,102
+	103,101,102
+	103,101,102
+	103,102
+	103,101,102
+	103,101,102
+
 =head2 quantity_possible_rules
 
 Returns the quantity of possible rules.
 
 =head2 generate_rules
 
-Generate association rules until no set of items meets the minimum support, confidence, lift, leverage, conviction, coverage or limit of rules.
+Generate association rules until no set of items meets the minimum support, confidence, lift, leverage, conviction, coverage, correlation, cosine, laplace, jaccard or limit of rules.
 
 =head2 association_rules
 
